==> haskell-retry-0.7.4.2-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.7.4.2
id: retry-0.7.4.2-E6erOdhQE7831rjh0wtpDA
key: retry-0.7.4.2-E6erOdhQE7831rjh0wtpDA
license: BSD3
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
author: Ozgun Ataman
exposed: True
indefinite: False
exposed-modules:
    Control.Retry
abi: 892b4bee1c4a036d3284355c4a71ed4a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/retry-0.7.4.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/retry-0.7.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/retry-0.7.4.2
hs-libraries: HSretry-0.7.4.2-E6erOdhQE7831rjh0wtpDA
depends:
    base-4.10.0.0 data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 ghc-prim-0.5.1.0
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK transformers-0.5.2.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=55d8edbe337279f21d58496f3f779cb9
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-retry-0.7.4.3-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.7.4.3
id: retry-0.7.4.3-8Vejk5ADE7VDV7dQ8GP3MX
key: retry-0.7.4.3-8Vejk5ADE7VDV7dQ8GP3MX
license: BSD3
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
author: Ozgun Ataman
exposed: True
indefinite: False
exposed-modules:
    Control.Retry
abi: 5f20f15a12cdd4af57eedb56dd364668
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/retry-0.7.4.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/retry-0.7.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/retry-0.7.4.3
hs-libraries: HSretry-0.7.4.3-8Vejk5ADE7VDV7dQ8GP3MX
depends:
    base-4.10.0.0 data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 ghc-prim-0.5.1.0
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK transformers-0.5.2.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=55d8edbe337279f21d58496f3f779cb9
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
